@@ -13,7 +13,7 @@ sub init {
 		security => {
 			api_key => sub {
 				my ($c, $definition, $scopes, $cb) = @_;
-				if(exists($c->session->{apikey})) {
+				if(exists($c->session->{apikey}) && defined($c->req->headers->header("X-SReview-Key"))) {
 					return $c->$cb('API key invalid') unless $c->session->{apikey} eq $c->req->headers->header("X-SReview-Key");
 					return $c->$cb();
 				}
@@ -1761,6 +1761,7 @@ components:
           - notification
           - preview
           - transcoding
+          - fixuping
           - uploading
           - publishing
           - notify_final
@@ -1774,6 +1775,7 @@ components:
           - needs_work
           - lost
           - ignored
+          - uninteresting
         progress:
           type: string
           default: waiting
